@@ -14,19 +14,15 @@ from .sessions import (
     ClientSession,
     ServerSession,
     CodeSession,
-    CodeClientSession,
     CodeServerSession,
     ImplicitSession,
     ImplicitClientSession,
-    ImplicitServerSession,
     PasswordSession,
     PasswordClientSession,
-    PasswordServerSession,
     RefreshSession,
-    RefreshClientSession,
     RefreshServerSession,
 )
 from .api import API
 
 
-__version__ = '0.1.0'
+__version__ = '0.1.1.post1'
